package customer

import (
	"errors"
	"net/http"
	"spaceofcheng/services/controllers"
	"spaceofcheng/services/models"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/service/customer"
	"spaceofcheng/services/utils"
)

// CustomerController 用户
type CustomerController struct {
	serv *customer.CustomerServ
	controllers.BaseController
}

// Constructor 初始化 Controller
// @Title Constructor
// @Description 初始化 Controller, 系统自动调用
func (c *CustomerController) Constructor() {
	c.serv = customer.NewCustomerServ(c.Context)
}

// CustWXList 获取客户列表
func (c *CustomerController) CustWXList() {
	phone := c.GetString("phone")
	page, _ := c.GetInt("page")

	custList, total, err := c.serv.GetCustWithWXList(phone, page)
	if err != nil {
		utils.LogError("获取客户列表失败: " + err.Error())
		c.ResponseError(
			errors.New("获取客户列表失败"),
			http.StatusInternalServerError,
		)
	}

	c.ResponseJSON(map[string]interface{}{
		"list":  custList,
		"total": total,
	})
}

// GetCustOrUserByID 获取用户信息
func (c *CustomerController) GetCustOrUserByID() {
	userMapRaw := c.Context.Get("userMap")
	if userMapRaw == nil {
		c.ResponseError(errors.New("获取用户信息失败, 请确认使用微信浏览"))
	}

	userMap := userMapRaw.(model.TaUserMapping)

	if userMap.UserType == models.USERMAP_USER {
		// 如果是用户
		userID := userMap.UserId
		user, err := c.serv.GetCustUserByID(userID)
		if err != nil {
			utils.LogError(err)
			c.ResponseError(errors.New("获取用户信息失败, 请重试"))
		}

		c.ResponseJSON(map[string]interface{}{
			"user":     user,
			"userType": userMap.UserType,
		})
	} else {
		// 如果是客户
		custID := userMap.UserId
		cust, err := c.serv.GetCustWithWXByID(custID)
		if err != nil {
			utils.LogError(err)
			c.ResponseError(errors.New("获取用户信息失败, 请重试"))
		}

		c.ResponseJSON(map[string]interface{}{
			"customer": cust,
			"userType": userMap.UserType,
		})
	}
}
