package service

import (
	"encoding/json"
	"spaceofcheng/services/models"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/utils"
)

const (
	PAGENUM = 10
)

// SysServ 系统处理
type SysServ struct {
	ctx *utils.Context
	dao *models.SysDAO
}

// NewSysServ 初始化
func NewSysServ(ctx *utils.Context) *SysServ {
	return &SysServ{
		ctx: ctx,
		dao: models.NewSysDAO(ctx),
	}
}

// SetUserProfile 设置用户信息
func (s *SysServ) SetUserProfile(id string) error {
	user, err := s.dao.GetPureUserInfo(id)
	if err != nil {
		return utils.LogError("获取用户基本信息失败: " + err.Error())
	}
	s.ctx.Set("user", *user)

	cases, err := s.dao.GetUserCase(id)
	if err != nil {
		return utils.LogError("获取用户案场信息失败: " + err.Error())
	}
	s.ctx.Set("cases", cases)

	found := false
	for _, cs := range cases {
		if cs.IsBelong == models.BOOL_TRUE {
			found = true
			s.ctx.Set("currentCase", cs)
		}
	}

	if !found {
		return utils.LogError("用户没有设置默认案场")
	}

	org, err := s.dao.GetOrg(user.OrgId)
	if err != nil {
		return utils.LogError("获取用户组织信息失败: " + err.Error())
	}
	s.ctx.Set("org", *org)

	return nil
}

// SetCustomer 设置客户信息
func (s *SysServ) SetCustomer(id string) error {
	cust, err := s.dao.GetCustomer(id)
	if err != nil {
		return utils.LogError("获取客户基本信息失败: " + err.Error())
	}

	s.ctx.Set("customer", *cust)
	return nil
}

// CheckWechatUserMapping 校验并更新客户信息
// 如果不存在, 则插入新数据
func (s *SysServ) CheckWechatUserMapping(user map[string]interface{}, userType string) (*model.TaUserMapping, error) {
	openID := user["openid"].(string)
	uuID := ""
	uuidRaw, ok := user["unionid"]
	if ok {
		uuID = uuidRaw.(string)
	}

	accountRaw, err := json.Marshal(user)
	if err != nil {
		return nil, err
	}
	account := string(accountRaw)

	userMapping := model.TaUserMapping{
		UserType:    userType,
		AccountType: models.ACCMAP_WECHAT,
		Openid:      openID,
		Uuid:        uuID,
		AccountInfo: account,
	}

	if err := s.dao.CheckUserMappingByOpenID(&userMapping); err != nil {
		return nil, err
	}

	return &userMapping, nil
}
